@@ -1,19 +1,15 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, division, print_function
-
 import warnings
 from typing import Optional, Union
 
-import numpy as np
 import pandas as pd
 import pydaymet.pet as daypet
-import typic
-from solarpy import declination
-from tstoolbox import tsutils
+from numpy import exp
+from pydantic import PositiveInt, confloat, validate_arguments
+from toolbox_utils import tsutils
 from tstoolbox.tstoolbox import read
 
-from . import meteolib, utils
+from . import utils
+from .meteo_utils import calc_ea, calc_es, daylight_hours
 
 warnings.filterwarnings("ignore")
 
@@ -22,13 +18,11 @@ def _columns(tsd, req_column_list=[], optional_column_list=[]):
     if None in req_column_list:
         raise ValueError(
             tsutils.error_wrapper(
-                """
+                f"""
 You need to supply the column (name or number, data column numbering
-starts at 1) for {} time-series.
+starts at 1) for {len(req_column_list)} time-series.
 
-Instead you gave {}""".format(
-                    len(req_column_list), req_column_list
-                )
+Instead you gave {req_column_list}"""
             )
         )
 
@@ -47,6 +41,51 @@ Instead you gave {}""".format(
     return collect
 
 
+def _temp_read(
+    temp_min_col,
+    temp_max_col,
+    temp_mean_col,
+    source_units,
+    start_date=None,
+    end_date=None,
+    dropna="no",
+    clean=False,
+    round_index=None,
+    skiprows=None,
+    index_type="datetime",
+):
+    if temp_mean_col is None:
+        tsd = tsutils.common_kwds(
+            input_tsd=[temp_min_col, temp_max_col],
+            names=["tmin", "tmax"],
+            source_units=source_units,
+            target_units=["degC", "degC"],
+            start_date=start_date,
+            end_date=end_date,
+            dropna=dropna,
+            clean=clean,
+            round_index=round_index,
+            skiprows=skiprows,
+            index_type=index_type,
+        )
+        tsd["tmean:degC"] = (tsd["tmin:degC"] + tsd["tmax:degC"]) / 2
+    else:
+        tsd = tsutils.common_kwds(
+            input_tsd=[temp_min_col, temp_max_col, temp_max_col],
+            names=["tmin", "tmax", "tmean"],
+            source_units=source_units,
+            target_units=["degC", "degC", "degC"],
+            start_date=start_date,
+            end_date=end_date,
+            dropna=dropna,
+            clean=clean,
+            round_index=round_index,
+            skiprows=skiprows,
+            index_type=index_type,
+        )
+    return tsd
+
+
 def _preprocess(
     input_ts,
     temp_min_col,
@@ -71,7 +110,6 @@ def _preprocess(
         temp_min_required=temp_min_required,
         temp_max_required=temp_max_required,
     )
-
     tsd = tsutils.common_kwds(
         input_ts,
         skiprows=skiprows,
@@ -167,89 +205,214 @@ def et0_pm(
     return tsd
 
 
-@typic.constrained(ge=-90, le=90)
-class FloatLatitude(float):
-    """-90 <= float <= 90"""
+@validate_arguments
+def blaney_criddle(
+    bright_hours_col,
+    source_units: Optional[Union[str, list]],
+    temp_mean_col=None,
+    temp_min_col=None,
+    temp_max_col=None,
+    k=0.85,
+    start_date=None,
+    end_date=None,
+    dropna="no",
+    clean=False,
+    round_index=None,
+    skiprows=None,
+    names=None,
+    target_units="mm",
+    print_input=False,
+):
+    """Evaporation calculated according to [blaney_1952]_."""
+    tsd = _temp_read(
+        temp_min_col,
+        temp_max_col,
+        temp_mean_col,
+        source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        names=names,
+    )
+    bright_hours = tsutils.common_kwds(
+        bright_hours_col,
+        start_date=start_date,
+        end_date=end_date,
+        round_index=round_index,
+        dropna=dropna,
+        clean=clean,
+    )
 
+    pet = k * bright_hours * (0.46 * tsd["tmean:degC"] + 8.13)
+    pet.columns = ["pet_blaney_criddle:mm"]
 
-@typic.constrained(ge=-180, le=180)
-class FloatLongitude(float):
-    """-180 <= float <= 180"""
+    if target_units != source_units:
+        pet = tsutils.common_kwds(pet, source_units="mm", target_units=target_units)
+    return tsutils.return_input(print_input, tsd, pet)
 
 
-@typic.constrained(gt=0)
-class FloatGreaterThanZero(float):
-    """0 < float"""
-
-
-@typic.al
+@validate_arguments
 def hamon(
-    lat: FloatLatitude,
-    temp_min_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_max_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_mean_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]] = None,
-    k: float = 1,
-    source_units=None,
-    input_ts="-",
+    lat: confloat(ge=-90, le=90),
+    source_units: Optional[Union[str, list]],
+    temp_mean_col=None,
+    temp_min_col=None,
+    temp_max_col=None,
     start_date=None,
     end_date=None,
     dropna="no",
     clean=False,
     round_index=None,
     skiprows=None,
-    index_type="datetime",
     names=None,
     target_units=None,
     print_input=False,
 ):
-    """hamon"""
-    temp_min_required = True
-    temp_max_required = True
-    tsd = _preprocess(
-        input_ts,
+    """Evaporation calculated according to [hamon_1961]_."""
+    tsd = _temp_read(
         temp_min_col,
         temp_max_col,
         temp_mean_col,
-        temp_min_required,
-        temp_max_required,
-        skiprows,
-        names,
-        index_type,
-        start_date,
-        end_date,
-        round_index,
-        dropna,
-        clean,
         source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        names=names,
     )
 
-    decl = [declination(i) for i in tsd.index.to_pydatetime()]
+    daylh = daylight_hours(tsd.index, lat)
 
-    w = np.arccos(-np.tan(decl) * np.tan(lat))
-
-    es = meteolib.es_calc(tsd.tmean)
-
-    N = 24 * w / np.pi
-
-    # Create new dataframe with tsd.index as index in
-    # order to get all of the time components correct.
-    pe = pd.DataFrame(0.0, index=tsd.index, columns=["pet_hamon:mm"])
-    pe["pet_hamon:mm"] = k * 29.8 * N * es / (273.3 + tsd.tmean)
-    pe.loc[tsd.tmean <= 0, "pet_hamon:mm"] = 0.0
+    pet = (daylh / 12) ** 2 * exp(tsd["tmean:degC"] / 16)
+    pet.columns = ["pet_hamon:mm"]
 
     if target_units != source_units:
-        pe = tsutils.common_kwds(pe, source_units="mm", target_units=target_units)
-    return tsutils.return_input(print_input, tsd, pe)
+        pet = tsutils.common_kwds(pet, source_units="mm", target_units=target_units)
+    return tsutils.return_input(print_input, tsd, pet)
 
 
-@typic.al
-def hargreaves(
-    lat: FloatLatitude,
-    temp_min_col: Optional[Union[tsutils.IntGreaterEqualToOne, str, list]],
-    temp_max_col: Optional[Union[tsutils.IntGreaterEqualToOne, str, list]],
+def romanenko(
     source_units: Optional[Union[str, list]],
-    temp_mean_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]] = None,
-    input_ts="-",
+    temp_mean_col=None,
+    temp_min_col=None,
+    temp_max_col=None,
+    rh_col=None,
+    k=4.5,
+    start_date=None,
+    end_date=None,
+    dropna="no",
+    clean=False,
+    round_index=None,
+    skiprows=None,
+    names=None,
+    target_units=None,
+    print_input=False,
+):
+    """Evaporation calculated according to [romanenko_1961]_."""
+    tsd = _temp_read(
+        temp_min_col,
+        temp_max_col,
+        temp_mean_col,
+        source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        names=names,
+    )
+    rh_col = tsutils.common_kwds(
+        rh_col,
+        start_date=start_date,
+        end_date=end_date,
+        round_index=round_index,
+        dropna=dropna,
+        clean=clean,
+    )
+
+    ea = calc_ea(tmean=tsd["tmean:degC"], rh=rh_col)
+    es = calc_es(tmean=tsd["tmean:degC"])
+
+    pet = k * (1 + tsd["tmean:degC"] / 25) ** 2 * (1 - ea / es)
+    pet.columns = ["pet_romanenko:mm"]
+
+    if target_units != source_units:
+        pet = tsutils.common_kwds(pet, source_units="mm", target_units=target_units)
+    return tsutils.return_input(print_input, tsd, pet)
+
+
+def linacre(
+    lat: confloat(ge=-90, le=90),
+    elevation,
+    source_units: Optional[Union[str, list]],
+    temp_mean_col=None,
+    temp_min_col=None,
+    temp_max_col=None,
+    tdew_col=None,
+    start_date=None,
+    end_date=None,
+    dropna="no",
+    clean=False,
+    round_index=None,
+    skiprows=None,
+    names=None,
+    target_units=None,
+    print_input=False,
+):
+    """Evaporation calculated according to [linacre_1977]_."""
+    tsd = _temp_read(
+        temp_min_col,
+        temp_max_col,
+        temp_mean_col,
+        source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        names=names,
+    )
+    tdew_col = tsutils.common_kwds(
+        tdew_col,
+        start_date=start_date,
+        end_date=end_date,
+        round_index=round_index,
+        dropna=dropna,
+        clean=clean,
+    )
+
+    if tdew_col is None:
+        tdew_col = (
+            0.52 * tsd["tmin:degC"]
+            + 0.6 * tsd["tmax:degC"]
+            - 0.009 * tsd["tmax:degC"] ** 2
+            - 2
+        )
+    tm = tsd["tmean:degC"] + 0.006 * elevation
+    pet = (500 * tm / (100 - lat) + 15 * (tsd["tmean:degC"] - tdew_col)) / (
+        80 - tsd["tmean:degC"]
+    )
+    pet.columns = ["pet_linacre:mm"]
+
+    if target_units != source_units:
+        pet = tsutils.common_kwds(pet, source_units="mm", target_units=target_units)
+    return tsutils.return_input(print_input, tsd, pet)
+
+
+@validate_arguments
+def hargreaves(
+    lat: confloat(ge=-90, le=90),
+    temp_min_col: Optional[Union[PositiveInt, str, list]],
+    temp_max_col: Optional[Union[PositiveInt, str, list]],
+    source_units: Optional[Union[str, list]],
+    temp_mean_col: Optional[Union[PositiveInt, str]] = None,
     start_date=None,
     end_date=None,
     dropna="no",
@@ -268,29 +431,23 @@ def hargreaves(
     #
     # If temp_min_col, temp_max_col, or temp_mean_col do not have a "," then
     # they are integer column numbers or string column names in "input_ts".
-    from tstoolbox.tstoolbox import read
 
-    if temp_mean_col is None:
-        tsd = read(
-            temp_min_col,
-            temp_max_col,
-            names=["tmin", "tmax"],
-            source_units=source_units,
-            target_units=["degC", "degC"],
-        )
-        tsd["tmean:degC"] = (tsd["tmin:degC"] + tsd["tmax:degC"]) / 2
-    else:
-        tsd = read(
-            temp_min_col,
-            temp_max_col,
-            temp_max_col,
-            names=["tmin", "tmax", "tmean"],
-            source_units=source_units,
-            target_units=["degC", "degC", "degC"],
-        )
+    tsd = _temp_read(
+        temp_min_col,
+        temp_max_col,
+        temp_mean_col,
+        source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        index_type=index_type,
+        names=names,
+    )
 
     newra = utils.radiation(tsd, lat)
-
     tsdiff = tsd["tmax:degC"] - tsd["tmin:degC"]
 
     # Create new dataframe with tsd.index as index in
@@ -309,16 +466,15 @@ def hargreaves(
     return tsutils.return_input(print_input, tsd, pe)
 
 
-@typic.al
+@validate_arguments
 def oudin_form(
-    lat: FloatLatitude,
-    temp_min_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_max_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_mean_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]] = None,
+    lat: confloat(ge=-90, le=90),
+    temp_min_col: Optional[Union[PositiveInt, str]],
+    temp_max_col: Optional[Union[PositiveInt, str]],
+    temp_mean_col: Optional[Union[PositiveInt, str]] = None,
     k1=100,
     k2=5,
     source_units=None,
-    input_ts="-",
     start_date=None,
     end_date=None,
     dropna="no",
@@ -331,24 +487,19 @@ def oudin_form(
     print_input=False,
 ):
     """oudin form"""
-    temp_min_required = False
-    temp_max_required = False
-    tsd = _preprocess(
-        input_ts,
+    tsd = _temp_read(
         temp_min_col,
         temp_max_col,
         temp_mean_col,
-        temp_min_required,
-        temp_max_required,
-        skiprows,
-        names,
-        index_type,
-        start_date,
-        end_date,
-        round_index,
-        dropna,
-        clean,
         source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        index_type=index_type,
+        names=names,
     )
 
     newra = utils.radiation(tsd, lat)
@@ -360,8 +511,8 @@ def oudin_form(
     gamma = 2.45  # the latent heat flux (MJ kg−1)
     rho = 1000.0  # density of water (kg m-3)
 
-    pe.loc[tsd.tmean > k2, "pet_oudin:mm"] = (
-        newra.ra / (gamma * rho) * (tsd.tmean + k2) / k1 * 1000
+    pe.loc[tsd["tmean"] > k2, "pet_oudin:mm"] = (
+        newra.ra / (gamma * rho) * (tsd["tmean"] + k2) / k1 * 1000
     )
 
     if target_units != source_units:
@@ -369,14 +520,13 @@ def oudin_form(
     return tsutils.return_input(print_input, tsd, pe)
 
 
-@typic.al
+@validate_arguments
 def allen(
-    lat: FloatLatitude,
-    temp_min_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_max_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]],
-    temp_mean_col: Optional[Union[tsutils.IntGreaterEqualToOne, str]] = None,
-    source_units=None,
-    input_ts="-",
+    lat: confloat(ge=-90, le=90),
+    temp_min_col: Optional[Union[PositiveInt, str]],
+    temp_max_col: Optional[Union[PositiveInt, str]],
+    source_units: Optional[Union[str, list]],
+    temp_mean_col: Optional[Union[PositiveInt, str]] = None,
     start_date=None,
     end_date=None,
     dropna="no",
@@ -389,24 +539,19 @@ def allen(
     print_input=False,
 ):
     """Allen"""
-    temp_min_required = False
-    temp_max_required = False
-    tsd = _preprocess(
-        input_ts,
+    tsd = _temp_read(
         temp_min_col,
         temp_max_col,
         temp_mean_col,
-        temp_min_required,
-        temp_max_required,
-        skiprows,
-        names,
-        index_type,
-        start_date,
-        end_date,
-        round_index,
-        dropna,
-        clean,
         source_units,
+        start_date=start_date,
+        end_date=end_date,
+        dropna=dropna,
+        clean=clean,
+        round_index=round_index,
+        skiprows=skiprows,
+        index_type=index_type,
+        names=names,
     )
 
     newra = utils.radiation(tsd, lat)
@@ -416,7 +561,11 @@ def allen(
     pe = pd.DataFrame(0.0, index=tsd.index, columns=["pet_allen:mm"])
 
     pe["pet_allen:mm"] = (
-        0.408 * 0.0029 * newra.ra * (tsd.tmax - tsd.tmin) ** 0.4 * (tsd.tmean + 20)
+        0.408
+        * 0.0029
+        * newra.ra
+        * (tsd["tmax:degC"] - tsd["tmin:degC"]) ** 0.4
+        * (tsd["tmean:degC"] + 20)
     )
 
     if target_units != source_units:
@@ -446,14 +595,14 @@ def prepare_daymet(
     return tsd
 
 
-@typic.al
-def priestly_taylor(
-    lat: FloatLatitude,
-    lon: FloatLongitude,
-    tmin_col: Optional[Union[tsutils.IntGreaterEqualToOne, str, list]],
-    tmax_col: Optional[Union[tsutils.IntGreaterEqualToOne, str, list]],
-    srad_col: Optional[Union[FloatGreaterThanZero, str, list]],
-    dayl_col: Optional[Union[FloatGreaterThanZero, str, list]],
+@validate_arguments
+def priestley_taylor(
+    lat: confloat(ge=-90, le=90),
+    lon: confloat(ge=-180, le=180),
+    tmin_col: Optional[Union[PositiveInt, str, list]],
+    tmax_col: Optional[Union[PositiveInt, str, list]],
+    srad_col: Optional[Union[PositiveInt, str, list]],
+    dayl_col: Optional[Union[PositiveInt, str, list]],
     source_units: Optional[Union[str, list]],
     rh_col=None,
     u2_col=None,
@@ -469,8 +618,7 @@ def priestly_taylor(
     target_units="mm",
     print_input=False,
 ):
-    """priestly_taylor"""
-
+    """priestley_taylor"""
     if isinstance(input_ts, (pd.DataFrame, pd.Series)):
         tsd = input_ts
     else:
@@ -499,11 +647,53 @@ def priestly_taylor(
     return tsutils.return_input(print_input, tsd, pe)
 
 
-def reference():
+@validate_arguments
+def penman_monteith(
+    lat: confloat(ge=-90, le=90),
+    lon: confloat(ge=-180, le=180),
+    tmin_col: Optional[Union[PositiveInt, str, list]],
+    tmax_col: Optional[Union[PositiveInt, str, list]],
+    srad_col: Optional[Union[PositiveInt, str, list]],
+    dayl_col: Optional[Union[PositiveInt, str, list]],
+    source_units: Optional[Union[str, list]],
+    rh_col=None,
+    u2_col=None,
+    input_ts="-",
+    start_date=None,
+    end_date=None,
+    dropna="no",
+    clean=False,
+    round_index=None,
+    skiprows=None,
+    index_type="datetime",
+    names=None,
+    target_units="mm",
+    print_input=False,
+):
     """reference penman-monteith"""
-    print("reference")
+    if isinstance(input_ts, (pd.DataFrame, pd.Series)):
+        tsd = input_ts
+    else:
+        tsd = prepare_daymet(
+            tmin_col,
+            tmax_col,
+            srad_col,
+            dayl_col,
+            rh_col,
+            u2_col,
+            source_units,
+            target_units,
+        )
+    rename = {
+        "tmin:degC": "tmin (degrees C)",
+        "tmax:degC": "tmax (degrees C)",
+        "srad:W/m^2": "srad (W/m2)",
+        "dayl:s": "dayl (s)",
+        "rh:": "rh",
+        "u2:m/s": "u2 (m/s)",
+    }
+    tsd = tsd.rename(columns=rename)
 
-
-def potential():
-    """potential"""
-    print("potential")
+    pe = daypet.PETCoords(tsd, (lon, lat))
+    pe = pe.penman_monteith().iloc[:, -1]
+    return tsutils.return_input(print_input, tsd, pe)
